@@ -7,23 +7,23 @@ module.exports = (api) => {
   return {
     presets: [
       [
-        '@babel/preset-env',
+        "@babel/preset-env",
         {
           targets: {
-            node: '10.13.0',
+            node: "12.13.0",
           },
         },
       ],
     ],
     overrides: [
       {
-        test: '**/hmr/**/*.js',
+        test: "**/hmr/**/*.js",
         presets: [
           [
-            '@babel/preset-env',
+            "@babel/preset-env",
             {
               targets: {
-                node: '0.12',
+                node: "0.12",
               },
             },
           ],
