@@ -2,10 +2,14 @@
  * @jest-environment node
  */
 
-import fs from 'fs';
-import path from 'path';
+import fs from "fs";
+import path from "path";
 
-import webpack from 'webpack';
+import webpack from "webpack";
+
+import Self from "../src/index";
+
+import yn from "./helpers/yn";
 
 function clearDirectory(dirPath) {
   let files;
@@ -44,14 +48,14 @@ function compareDirectory(actual, expected) {
         path.resolve(expected, file)
       );
     } else if (stats.isFile()) {
-      const content = fs.readFileSync(path.resolve(expected, file), 'utf8');
+      const content = fs.readFileSync(path.resolve(expected, file), "utf8");
       let actualContent;
 
       if (/^MISSING/.test(content)) {
         expect(fs.existsSync(path.resolve(actual, file))).toBe(false);
       } else {
         try {
-          actualContent = fs.readFileSync(path.resolve(actual, file), 'utf8');
+          actualContent = fs.readFileSync(path.resolve(actual, file), "utf8");
         } catch (error) {
           // eslint-disable-next-line no-console
           console.log(error);
@@ -68,17 +72,17 @@ function compareDirectory(actual, expected) {
   }
 }
 
-describe('TestCases', () => {
-  const casesDirectory = path.resolve(__dirname, 'cases');
-  const outputDirectory = path.resolve(__dirname, 'js');
+describe("TestCases", () => {
+  const casesDirectory = path.resolve(__dirname, "cases");
+  const outputDirectory = path.resolve(__dirname, "js");
   const tests = fs.readdirSync(casesDirectory).filter((test) => {
     const testDirectory = path.join(casesDirectory, test);
-    const filterPath = path.join(testDirectory, 'test.filter.js');
+    const filterPath = path.join(testDirectory, "test.filter.js");
 
     // eslint-disable-next-line global-require, import/no-dynamic-require
     if (fs.existsSync(filterPath) && !require(filterPath)()) {
       describe.skip(test, () => {
-        it('filtered', () => {});
+        it("filtered", () => {});
       });
 
       return false;
@@ -90,16 +94,11 @@ describe('TestCases', () => {
   clearDirectory(outputDirectory);
 
   for (const directory of tests) {
-    if (directory === 'auxiliaryAssets' && webpack.version[0] === '4') {
-      // eslint-disable-next-line no-continue
-      continue;
-    }
-
     if (!/^(\.|_)/.test(directory)) {
       // eslint-disable-next-line no-loop-func
       it(`${directory} should compile to the expected result`, (done) => {
-        if (directory === 'serializingBigStrings') {
-          clearDirectory(path.resolve(__dirname, '../node_modules/.cache'));
+        if (directory === "serializingBigStrings") {
+          clearDirectory(path.resolve(__dirname, "../node_modules/.cache"));
         }
 
         const directoryForCase = path.resolve(casesDirectory, directory);
@@ -107,43 +106,86 @@ describe('TestCases', () => {
         // eslint-disable-next-line import/no-dynamic-require, global-require
         const webpackConfig = require(path.resolve(
           directoryForCase,
-          'webpack.config.js'
+          "webpack.config.js"
         ));
+        const { context } = webpackConfig;
 
         for (const config of [].concat(webpackConfig)) {
           Object.assign(
             config,
             {
-              mode: 'none',
+              mode: config.mode || "none",
               context: directoryForCase,
+            },
+            config,
+            {
               output: Object.assign(
                 {
                   path: outputDirectoryForCase,
                 },
                 config.output
               ),
+              plugins:
+                config.plugins &&
+                config.plugins.map((p) => {
+                  if (p.constructor === Self) {
+                    const { options } = p;
+
+                    const useImportModule = yn(process.env.OLD_API);
+
+                    if (useImportModule === true) {
+                      options.experimentalUseImportModule = false;
+                    }
+                  }
+
+                  return p;
+                }),
             },
-            config
+            context ? { context } : {}
           );
         }
 
-        webpack(webpackConfig, (err, stats) => {
-          if (err) {
-            done(err);
-            return;
-          }
-          if (stats.hasErrors()) {
-            done(new Error(stats.toString()));
+        webpack(webpackConfig, (error, stats) => {
+          if (error) {
+            done(error);
+
             return;
           }
 
-          done();
+          if (stats.hasErrors()) {
+            const errorsPath = path.join(directoryForCase, "./errors.test.js");
+
+            if (fs.existsSync(errorsPath)) {
+              const { errors } = stats.compilation;
+              // eslint-disable-next-line global-require, import/no-dynamic-require
+              const errorFilters = require(errorsPath);
+              const filteredErrors = errors.filter(
+                // eslint-disable-next-line no-shadow
+                (error) =>
+                  !errorFilters.some((errorFilter) => errorFilter.test(error))
+              );
+
+              if (filteredErrors.length > 0) {
+                done(new Error(`Errors:\n${filteredErrors.join(",\n")}`));
+
+                return;
+              }
+
+              done();
+
+              return;
+            }
+
+            done(new Error(stats.toString()));
+
+            return;
+          }
 
           if (stats.hasErrors() && stats.hasWarnings()) {
             done(
               new Error(
                 stats.toString({
-                  context: path.resolve(__dirname, '..'),
+                  context: path.resolve(__dirname, ".."),
                   errorDetails: true,
                   warnings: true,
                 })
@@ -153,45 +195,37 @@ describe('TestCases', () => {
             return;
           }
 
-          const expectedDirectory = path.resolve(directoryForCase, 'expected');
+          const expectedDirectory = path.resolve(directoryForCase, "expected");
           const expectedDirectoryByVersion = path.join(
             expectedDirectory,
-            `webpack-${webpack.version[0]}`
+            `webpack-${webpack.version[0]}${
+              yn(process.env.OLD_API) ? "" : "-importModule"
+            }`
           );
 
           if (/^hmr/.test(directory)) {
             let res = fs
-              .readFileSync(path.resolve(outputDirectoryForCase, 'main.js'))
+              .readFileSync(path.resolve(outputDirectoryForCase, "main.js"))
               .toString();
 
             const date = Date.now().toString().slice(0, 6);
-            const dateRegexp = new RegExp(`${date}\\d+`, 'gi');
+            const dateRegexp = new RegExp(`${date}\\d+`, "gi");
 
-            res = res.replace(dateRegexp, '');
+            res = res.replace(dateRegexp, "");
 
-            if (webpack.version[0] === '4') {
-              const matchAll = res.match(/var hotCurrentHash = "([\d\w].*)"/i);
-              const replacer = new Array(matchAll[1].length);
+            const matchAll = res.match(
+              /__webpack_require__\.h = \(\) => \(("[\d\w].*")\)/i
+            );
 
-              res = res.replace(
-                /var hotCurrentHash = "([\d\w].*)"/i,
-                `var hotCurrentHash = "${replacer.fill('x').join('')}"`
-              );
-            } else {
-              const matchAll = res.match(
-                /__webpack_require__\.h = \(\) => "([\d\w].*)"/i
-              );
+            const replacer = new Array(matchAll[1].length);
 
-              const replacer = new Array(matchAll[1].length);
-
-              res = res.replace(
-                /__webpack_require__\.h = \(\) => "([\d\w].*)"/i,
-                `__webpack_require__.h = () => "${replacer.fill('x').join('')}"`
-              );
-            }
+            res = res.replace(
+              /__webpack_require__\.h = \(\) => \(("[\d\w].*")\)/i,
+              `__webpack_require__.h = () => ("${replacer.fill("x").join("")}")`
+            );
 
             fs.writeFileSync(
-              path.resolve(outputDirectoryForCase, 'main.js'),
+              path.resolve(outputDirectoryForCase, "main.js"),
               res
             );
           }
@@ -205,7 +239,7 @@ describe('TestCases', () => {
             compareDirectory(outputDirectoryForCase, expectedDirectory);
           }
 
-          const warningsFile = path.resolve(directoryForCase, 'warnings.js');
+          const warningsFile = path.resolve(directoryForCase, "warnings.js");
 
           if (fs.existsSync(warningsFile)) {
             const actualWarnings = stats.toString({
@@ -218,11 +252,11 @@ describe('TestCases', () => {
             expect(
               actualWarnings
                 .trim()
-                .replace(/\*\scss\s(.*)?!/g, '* css /path/to/loader.js!')
+                .replace(/\*\scss\s(.*)?!/g, "* css /path/to/loader.js!")
             ).toBe(
               expectedWarnings
                 .trim()
-                .replace(/\*\scss\s(.*)?!/g, '* css /path/to/loader.js!')
+                .replace(/\*\scss\s(.*)?!/g, "* css /path/to/loader.js!")
             );
           }
 
