@@ -1,2 +1,2 @@
 // eslint-disable-next-line import/no-unresolved
-import './style.css';
+import "./style.css";
