@@ -1,8 +1,8 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
-  entry: './index.js',
-  devtool: 'source-map',
+  entry: "./index.js",
+  devtool: "source-map",
   module: {
     rules: [
       {
@@ -10,7 +10,7 @@ module.exports = {
         use: [
           Self.loader,
           {
-            loader: 'css-loader',
+            loader: "css-loader",
             options: {
               sourceMap: false,
             },
@@ -21,7 +21,7 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
