@@ -1,7 +1,7 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
-  entry: './index.js',
+  entry: "./index.js",
   module: {
     rules: [
       {
@@ -9,20 +9,14 @@ module.exports = {
         use: [
           {
             loader: Self.loader,
-            options: {
-              esModule: true,
-              modules: {
-                namedExport: true,
-              },
-            },
           },
           {
-            loader: 'css-loader',
+            loader: "css-loader",
             options: {
               esModule: true,
               modules: {
                 namedExport: true,
-                localIdentName: 'foo__[name]__[local]',
+                localIdentName: "foo__[name]__[local]",
               },
             },
           },
@@ -32,7 +26,7 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
