@@ -1,7 +1,7 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
-  entry: './index.js',
+  entry: "./index.js",
   module: {
     rules: [
       {
@@ -9,20 +9,23 @@ module.exports = {
         use: [
           {
             loader: Self.loader,
+          },
+          {
+            loader: "css-loader",
             options: {
-              publicPath: '',
+              esModule: false,
             },
           },
-          'css-loader',
         ],
       },
       {
         test: /\.svg$/,
+        type: "javascript/auto",
         use: [
           {
-            loader: 'file-loader',
+            loader: "file-loader",
             options: {
-              name: 'static/[name].[ext]',
+              name: "static/[name].[ext]",
             },
           },
         ],
@@ -31,7 +34,7 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
