@@ -1,9 +1,11 @@
-import { HotModuleReplacementPlugin } from 'webpack';
+import { HotModuleReplacementPlugin } from "webpack";
 
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
-  entry: './index.css',
+  entry: "./index.css",
+  mode: "development",
+  devtool: false,
   module: {
     rules: [
       {
@@ -12,7 +14,7 @@ module.exports = {
           {
             loader: Self.loader,
           },
-          'css-loader',
+          "css-loader",
         ],
       },
     ],
@@ -20,7 +22,7 @@ module.exports = {
   plugins: [
     new HotModuleReplacementPlugin(),
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
