@@ -1,17 +1,17 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
   entry: {
-    entry1: './index.js',
-    entry2: './index2.js',
-    entry3: './index3.js',
-    entry4: './index4.js',
+    entry1: "./index.js",
+    entry2: "./index2.js",
+    entry3: "./index3.js",
+    entry4: "./index4.js",
   },
   module: {
     rules: [
       {
         test: /\.css$/,
-        use: [Self.loader, 'css-loader'],
+        use: [Self.loader, "css-loader"],
       },
     ],
   },
@@ -19,8 +19,8 @@ module.exports = {
     splitChunks: {
       cacheGroups: {
         styles: {
-          name: 'styles',
-          chunks: 'all',
+          name: "styles",
+          chunks: "all",
           test: /\.css$/,
           enforce: true,
         },
