@@ -1,6 +1,6 @@
 /* global document */
 
-const Self = require('../../../src/cjs');
+const Self = require("../../../src/cjs");
 
 module.exports = {
   module: {
@@ -12,7 +12,7 @@ module.exports = {
             loader: Self.loader,
           },
           {
-            loader: 'css-loader',
+            loader: "css-loader",
           },
         ],
       },
@@ -20,11 +20,11 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
-      chunkFilename: '[id].css',
+      filename: "[name].css",
+      chunkFilename: "[id].css",
       // eslint-disable-next-line
       insert: function (linkTag) {
-        const reference = document.querySelector('.hot-reload');
+        const reference = document.querySelector(".hot-reload");
         if (reference) {
           reference.parentNode.insertBefore(linkTag, reference);
         }
