@@ -1,13 +1,13 @@
-import path from 'path';
+import path from "path";
 
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
   entry: {
     // Specific CSS entry point, with output to a nested folder
-    'nested/style': './nested/style.css',
+    "nested/style": "./nested/style.css",
     // Note that relative nesting of output is the same as that of the input
-    'nested/again/style': './nested/again/style.css',
+    "nested/again/style": "./nested/again/style.css",
   },
   module: {
     rules: [
@@ -21,28 +21,17 @@ module.exports = {
               publicPath: (resourcePath, context) =>
                 `${path
                   .relative(path.dirname(resourcePath), context)
-                  .replace(/\\/g, '/')}/`,
-            },
-          },
-          'css-loader',
-        ],
-      },
-      {
-        test: /\.(svg|png)$/,
-        use: [
-          {
-            loader: 'file-loader',
-            options: {
-              filename: '[name].[ext]',
+                  .replace(/\\/g, "/")}/`,
             },
           },
+          "css-loader",
         ],
       },
     ],
   },
   plugins: [
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
