@@ -1,8 +1,8 @@
-import Self from '../../../src/index';
+import Self from "../../../src/index";
 
 module.exports = {
-  cache: { type: 'filesystem' },
-  entry: 'bootstrap/dist/css/bootstrap.css',
+  cache: { type: "filesystem" },
+  entry: "bootstrap/dist/css/bootstrap.css",
   module: {
     rules: [
       {
@@ -10,7 +10,7 @@ module.exports = {
         use: [
           Self.loader,
           {
-            loader: 'css-loader',
+            loader: "css-loader",
             options: {
               sourceMap: true,
             },
@@ -24,8 +24,8 @@ module.exports = {
     new Self(),
     {
       apply(compiler) {
-        compiler.hooks.infrastructureLog.tap('test', (origin, type, args) => {
-          if (type === 'warn' || type === 'error') {
+        compiler.hooks.infrastructureLog.tap("test", (origin, type, args) => {
+          if (type === "warn" || type === "error") {
             throw new Error(`<${type}> [${origin}] ${args.toString()}`);
           }
         });
