@@ -1,21 +1,21 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
   entry: {
-    main: './index.js',
+    main: "./index.js",
   },
   module: {
     rules: [
       {
         test: /\.css$/,
-        use: [Self.loader, 'css-loader'],
+        use: [Self.loader, "css-loader"],
       },
     ],
   },
   plugins: [
     function Plugin() {
-      this.hooks.compilation.tap('Test', (compilation) => {
-        compilation.hooks.beforeChunkAssets.tap('Test', () => {
+      this.hooks.compilation.tap("Test", (compilation) => {
+        compilation.hooks.beforeChunkAssets.tap("Test", () => {
           for (const chunkGroup of compilation.chunkGroups) {
             // remove getModuleIndex2 to enforce using fallback
             // eslint-disable-next-line no-undefined
@@ -25,7 +25,7 @@ module.exports = {
       });
     },
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
