@@ -1,15 +1,15 @@
-import Self from '../../../src';
+import Self from "../../../src";
 
 module.exports = {
   entry: {
-    entry1: './entry1.js',
-    entry2: './entry2.js',
+    entry1: "./entry1.js",
+    entry2: "./entry2.js",
   },
   module: {
     rules: [
       {
         test: /\.css$/,
-        use: [Self.loader, 'css-loader'],
+        use: [Self.loader, "css-loader"],
       },
     ],
   },
@@ -17,8 +17,8 @@ module.exports = {
     splitChunks: {
       cacheGroups: {
         styles: {
-          name: 'styles',
-          chunks: 'all',
+          name: "styles",
+          chunks: "all",
           test: /\.css$/,
           enforce: true,
         },
@@ -27,7 +27,7 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
+      filename: "[name].css",
     }),
   ],
 };
