@@ -1,3 +1,3 @@
 // eslint-disable-next-line import/no-extraneous-dependencies
-import 'bootstrap.css';
-import './style.css';
+import "bootstrap.css";
+import "./style.css";
