@@ -1,19 +1,19 @@
-import path from 'path';
+import path from "path";
 
-import webpack from 'webpack';
+import webpack from "webpack";
 
-describe('IgnoreOrder', () => {
-  it('should emit warnings', (done) => {
-    const casesDirectory = path.resolve(__dirname, 'cases');
-    const directoryForCase = path.resolve(casesDirectory, 'ignoreOrderFalse');
+describe("IgnoreOrder", () => {
+  it("should emit warnings", (done) => {
+    const casesDirectory = path.resolve(__dirname, "cases");
+    const directoryForCase = path.resolve(casesDirectory, "ignoreOrderFalse");
     // eslint-disable-next-line import/no-dynamic-require, global-require
     const webpackConfig = require(path.resolve(
       directoryForCase,
-      'webpack.config.js'
+      "webpack.config.js"
     ));
     const compiler = webpack({
       ...webpackConfig,
-      mode: 'development',
+      mode: "development",
       context: directoryForCase,
       cache: false,
     });
@@ -23,17 +23,17 @@ describe('IgnoreOrder', () => {
     });
   });
 
-  it('should not emit warnings', (done) => {
-    const casesDirectory = path.resolve(__dirname, 'cases');
-    const directoryForCase = path.resolve(casesDirectory, 'ignoreOrder');
+  it("should not emit warnings", (done) => {
+    const casesDirectory = path.resolve(__dirname, "cases");
+    const directoryForCase = path.resolve(casesDirectory, "ignoreOrder");
     // eslint-disable-next-line import/no-dynamic-require, global-require
     const webpackConfig = require(path.resolve(
       directoryForCase,
-      'webpack.config.js'
+      "webpack.config.js"
     ));
     const compiler = webpack({
       ...webpackConfig,
-      mode: 'development',
+      mode: "development",
       context: directoryForCase,
       cache: false,
     });
