@@ -1,6 +1,6 @@
 /* eslint-env browser */
 /* eslint-disable no-alert */
 
-import './preloaded1.css';
+import "./preloaded1.css";
 
-alert('Ok');
+alert("Ok");
