@@ -1,6 +1,6 @@
 /* eslint-env browser */
 /* eslint-disable no-alert */
 
-import './preloaded2.css';
+import "./preloaded2.css";
 
-alert('Ok');
+alert("Ok");
