@@ -1,21 +1,27 @@
-const Self = require('../../');
+const yn = require("../helpers/yn");
+const Self = require("../../");
 
 const ENABLE_HMR =
-  typeof process.env.ENABLE_HMR !== 'undefined'
+  typeof process.env.ENABLE_HMR !== "undefined"
     ? Boolean(process.env.ENABLE_HMR)
     : true;
 
 const ENABLE_ES_MODULE =
-  typeof process.env.ES_MODULE !== 'undefined'
+  typeof process.env.ES_MODULE !== "undefined"
     ? Boolean(process.env.ES_MODULE)
     : true;
 
+const OLD_API =
+  typeof process.env.OLD_API !== "undefined" ? yn(process.env.OLD_API) : true;
+
+console.log(OLD_API);
+
 module.exports = {
-  mode: 'development',
+  mode: "development",
   output: {
-    chunkFilename: '[name].chunk.js',
-    publicPath: '/dist/',
-    crossOriginLoading: 'anonymous',
+    chunkFilename: "[name].chunk.js",
+    publicPath: "/dist/",
+    crossOriginLoading: "anonymous",
   },
   module: {
     rules: [
@@ -27,7 +33,7 @@ module.exports = {
             loader: Self.loader,
           },
           {
-            loader: 'css-loader',
+            loader: "css-loader",
             options: {
               esModule: ENABLE_ES_MODULE,
             },
@@ -44,7 +50,7 @@ module.exports = {
             },
           },
           {
-            loader: 'css-loader',
+            loader: "css-loader",
             options: {
               modules: true,
               esModule: ENABLE_ES_MODULE,
@@ -56,15 +62,16 @@ module.exports = {
   },
   plugins: [
     new Self({
-      filename: '[name].css',
-      chunkFilename: '[name].chunk.css',
+      filename: "[name].css",
+      chunkFilename: "[name].chunk.css",
+      experimentalUseImportModule: OLD_API,
     }),
   ],
   devServer: {
     hot: ENABLE_HMR,
-    contentBase: __dirname,
+    static: __dirname,
     headers: {
-      'Access-Control-Allow-Origin': '*',
+      "Access-Control-Allow-Origin": "*",
     },
   },
 };
